==> haskell-wai-app-static-3.1.6.3-74-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-app-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-app-static
version: 3.1.6.3
id: wai-app-static-3.1.6.3-IlirfTKNFq8KiAr40xTtG3
key: wai-app-static-3.1.6.3-IlirfTKNFq8KiAr40xTtG3
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/web-application-interface
synopsis: WAI application for static serving
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-app-static>.
category: Web, Yesod
abi: 606fd9a553aeee4326091c861204b422
exposed: True
exposed-modules:
    Network.Wai.Application.Static WaiAppStatic.CmdLine
    WaiAppStatic.Listing WaiAppStatic.Storage.Embedded
    WaiAppStatic.Storage.Filesystem WaiAppStatic.Types
hidden-modules: Util WaiAppStatic.Storage.Embedded.Runtime
                WaiAppStatic.Storage.Embedded.TH
import-dirs: /usr/lib/ghc-8.6.5/site-local/wai-app-static-3.1.6.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/wai-app-static-3.1.6.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/wai-app-static-3.1.6.3
hs-libraries: HSwai-app-static-3.1.6.3-IlirfTKNFq8KiAr40xTtG3
depends:
    base-4.12.0.0 blaze-html-0.9.1.1-2Y3dWG1bhOr3WT4vva2o1x
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q bytestring-0.10.8.2
    containers-0.6.0.1 cryptonite-0.26-CDY1m3syfqq9pANhaEyZh6
    directory-1.3.3.0 file-embed-0.0.11-4IE3sw0bCLQ7xXwEGMUYke
    filepath-1.4.2.1 http-date-0.0.8-7D9RBTtvkiDMZWtg7P4kd
    http-types-0.12.3-HyLqeUOIbzSKBEUtzZNX61
    memory-0.14.18-2FfCNwP2nzn4wBPtrz4oOB
    mime-types-0.1.0.9-2hmZJ5CmRudCuwA0xwTABk
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78
    optparse-applicative-0.14.3.0-8hy6ZL8cldl8WZw9XYPHX5
    template-haskell-2.14.0.0 text-1.2.3.1 time-1.8.0.2
    transformers-0.5.6.2 unix-compat-0.5.1-7L4ZE9qc5MBJa5Jne6W69O
    unordered-containers-0.2.10.0-DuDkJMfSb9t61flNcUovL1
    wai-3.2.2.1-JjUS7lyK8mHA1qZP8PSwDh
    wai-extra-3.0.27-GjnLsRBbwkv9BWHpKuqrCT
    warp-3.2.27-Aush8Hqf27YLLZpki0IzUx
    zlib-0.6.2-3orZ4PtYssfHtZIGrJhHYA
haddock-interfaces: /usr/share/doc/haskell-wai-app-static/html/wai-app-static.haddock
haddock-html: /usr/share/doc/haskell-wai-app-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-app-static-3.1.6.3-75-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-app-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-app-static
version: 3.1.6.3
id: wai-app-static-3.1.6.3-1V7UtasbLg5yXPlHksIGi
key: wai-app-static-3.1.6.3-1V7UtasbLg5yXPlHksIGi
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/web-application-interface
synopsis: WAI application for static serving
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-app-static>.
category: Web, Yesod
abi: dda7e420d7f020ad9b09d3324fd7804b
exposed: True
exposed-modules:
    Network.Wai.Application.Static WaiAppStatic.CmdLine
    WaiAppStatic.Listing WaiAppStatic.Storage.Embedded
    WaiAppStatic.Storage.Filesystem WaiAppStatic.Types
hidden-modules: Util WaiAppStatic.Storage.Embedded.Runtime
                WaiAppStatic.Storage.Embedded.TH
import-dirs: /usr/lib/ghc-8.6.5/site-local/wai-app-static-3.1.6.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/wai-app-static-3.1.6.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/wai-app-static-3.1.6.3
hs-libraries: HSwai-app-static-3.1.6.3-1V7UtasbLg5yXPlHksIGi
depends:
    base-4.12.0.0 blaze-html-0.9.1.1-2Y3dWG1bhOr3WT4vva2o1x
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q bytestring-0.10.8.2
    containers-0.6.0.1 cryptonite-0.26-CDY1m3syfqq9pANhaEyZh6
    directory-1.3.3.0 file-embed-0.0.11-4IE3sw0bCLQ7xXwEGMUYke
    filepath-1.4.2.1 http-date-0.0.8-7D9RBTtvkiDMZWtg7P4kd
    http-types-0.12.3-HyLqeUOIbzSKBEUtzZNX61
    memory-0.14.18-2FfCNwP2nzn4wBPtrz4oOB
    mime-types-0.1.0.9-2hmZJ5CmRudCuwA0xwTABk
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78
    optparse-applicative-0.14.3.0-8hy6ZL8cldl8WZw9XYPHX5
    template-haskell-2.14.0.0 text-1.2.3.1 time-1.8.0.2
    transformers-0.5.6.2 unix-compat-0.5.1-7L4ZE9qc5MBJa5Jne6W69O
    unordered-containers-0.2.10.0-DuDkJMfSb9t61flNcUovL1
    wai-3.2.2.1-KD2whrykQYM5hV5ErkjpaS
    wai-extra-3.0.27-8FWKAVE2g5EHw6nA69WHWi
    warp-3.2.27-GUDAYn8dc2cD1pshW2uID5
    zlib-0.6.2-3orZ4PtYssfHtZIGrJhHYA
haddock-interfaces: /usr/share/doc/haskell-wai-app-static/html/wai-app-static.haddock
haddock-html: /usr/share/doc/haskell-wai-app-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
